pub struct PinOptions {
pub host_nodes: Option<Vec<String>>,
pub custom_pin_policy: Option<PinPolicy>,
pub cid_version: Option<u8>,
}Expand description
Used to add additional options when pinning by hash
Fields
host_nodes: Option<Vec<String>>multiaddresses of nodes your content is already stored on
custom_pin_policy: Option<PinPolicy>Custom pin policy for the piece of content being pinned
cid_version: Option<u8>CID Version IPFS will use when creating a hash for your content